@@ -43,6 +43,18 @@ if [[ ${MODE} = distcheck ]]; then
     mkdir -p ~/rpmbuild/{BUILD,BUILDROOT,RPMS,SOURCES,SPECS,SRPMS}
     ln -v -s "$PWD"/expat-*.tar.bz2 ~/rpmbuild/SOURCES/
     rpmbuild -ba expat.spec
+elif [[ ${MODE} = cmake ]]; then
+    cmake .
+    make all test
+    make DESTDIR="${PWD}"/ROOT install
+    find ROOT -printf "%P\n" | sort
+elif [[ ${MODE} = cmake-oos ]]; then
+    mkdir build
+    cd build
+    cmake ..
+    make all test
+    make DESTDIR="${PWD}"/ROOT install
+    find ROOT -printf "%P\n" | sort
 else
     ./qa.sh "${MODE}"
 fi
